import { Component, For, Setter, Show } from 'solid-js';

import styles from './Dialog.module.css';
import { UploadFile, FileUploader } from '@solid-primitives/upload';

export interface DialogButton {
	name: string,
	action?: () => void,
	type?: 'default' | 'danger' | 'success',
	closeOnClick?: boolean
}

export interface DialogInputField {
	placeholder: string,
	onInput: (text: string) => void,
}

export interface ImageInputField {
	name: string,
	onInput: () => Setter<UploadFile[]>,
}

export interface DialogProps {
	title: string,
	text: string,
	buttons?: (string | DialogButton)[],
	onDismiss?: () => void,
	inputFields?: DialogInputField[],
}

function createButton(button: (string | DialogButton), dismiss?: () => void) { //TODO configurable if dismiss on click
	if (typeof button == 'string') {
		return <button onclick={dismiss} class={styles.defaultButton}>{button}</button>;
	} else {
		return <button onclick={() => { button.action?.(); button.closeOnClick ? dismiss?.() : () => { }; }} class={styles[button.type + 'Button']}>{button.name}</button>;
	}
}

function createInputField(field: DialogInputField) {
	return <input placeholder={field.placeholder} onInput={e => field.onInput(e.currentTarget.value)}></input>
}

const Dialog: Component<DialogProps> = props => {
	const buttons: () => (string | DialogButton)[] = () => props.buttons == null ? [{ name: 'Okay', action: props.onDismiss }] : props.buttons;

	return (
		<div class={styles.dialogContainer}>
			<div class={styles.dialog}>
				<div class={styles.dialogTitle}>{props.title}</div>
				<div class={styles.dialogText}>{props.text}</div>
				<div class={styles.dialogInputFields}>
					<For each={props.inputFields}>{f => createInputField(f)}</For>
				</div>
				<div class={styles.dialogButtons}>
					<For each={buttons()}>{b => createButton(b, props.onDismiss)}</For>
				</div>
			</div>
		</div>
	);
};

export default Dialog;
